@@ -22,11 +22,15 @@
 
 """This file test the WebScripts.py file"""
 
+from os import path, device_encoding
 from unittest import TestCase, main
+from unittest.mock import Mock
 from types import MethodType
 from typing import List
 from json import load
-from os import path
+import platform
+import locale
+import json
 import sys
 
 sys.path = [path.join(path.dirname(__file__), ".."), *sys.path]
@@ -41,13 +45,78 @@ from WebScripts.utils import (
     get_ini_dict,
     MissingAttributesError,
     WebScriptsConfigurationError,
+    LinuxLogs,
+    WindowsLogs,
+    Logs,
+    log_trace,
+    server_path,
 )
+import WebScripts.utils
+
+
+class TestLinuxLogs(TestCase):  # Code coverage, no tests on Logs functions
+    def setUp(self):
+        WebScripts.utils.syslog = Mock(
+            LOG_DEBUG=10, LOG_INFO=20, LOG_WARNING=30, LOG_ERR=40, LOG_CRIT=50
+        )
+        WebScripts.utils.ReportEvent = Mock()
+        self.logs = LinuxLogs
+
+    def test_debug(self):
+        self.logs.debug("test")
+
+    def test_info(self):
+        self.logs.info("test")
+
+    def test_warning(self):
+        self.logs.warning("test")
+
+    def test_error(self):
+        self.logs.error("test")
+
+    def test_critical(self):
+        self.logs.critical("test")
+
+
+class TestWindowsLogs(TestCase):  # Code coverage, no tests on Logs functions
+    def setUp(self):
+        WebScripts.utils.win32evtlog = Mock(
+            EVENTLOG_INFORMATION_TYPE=10,
+            EVENTLOG_WARNING_TYPE=20,
+            EVENTLOG_ERROR_TYPE=30,
+        )
+        WebScripts.utils.ReportEvent = Mock()
+        self.logs = WindowsLogs
+
+    def test_debug(self):
+        self.logs.debug("test")
+
+    def test_info(self):
+        self.logs.info("test")
+
+    def test_warning(self):
+        self.logs.warning("test")
+
+    def test_error(self):
+        self.logs.error("test")
+
+    def test_critical(self):
+        self.logs.critical("test")
+
+
+class TestLogs(TestCase):  # Code coverage, no tests on Logs functions
+    def test_exception(self):
+        Logs.exception("test")
 
 
 class TestDefaultNamespace(TestCase):
     def setUp(self):
         self.default_namespace = DefaultNamespace()
 
+    def test_constructor(self):
+        default_namespace = DefaultNamespace(default={"test": "test"})
+        self.assertEqual(default_namespace.test, "test")
+
     def test_update(self):
         self.default_namespace.update(test="test")
 
@@ -171,10 +240,12 @@ class TestDefaultNamespace(TestCase):
         self.default_namespace.int = "error"
         with self.assertRaises(WebScriptsConfigurationError):
             self.default_namespace.build_types()
+        self.default_namespace.int = "5"
 
         self.default_namespace.bool = "error"
         with self.assertRaises(WebScriptsConfigurationError):
             self.default_namespace.build_types()
+        self.default_namespace.bool = "true"
 
         self.default_namespace.listError = "1,2,3,d"
         with self.assertRaises(WebScriptsConfigurationError):
@@ -212,5 +283,82 @@ class TestDefaultNamespace(TestCase):
         )
 
 
+class TestFunctions(TestCase):
+    @staticmethod
+    @log_trace
+    def log_trace_staticmethod():
+        pass
+
+    def log_trace():
+        pass
+
+    def test_log_trace(self):  # Code coverage, no tests on Logs functions
+        self.log_trace_staticmethod()
+        self.static = staticmethod(self.log_trace)
+        self.trace = log_trace(self.static)
+        # self.static()
+
+    def test_get_encodings(self):
+        encodings = ["utf-8", "cp1252", "latin-1"]
+
+        if device_encoding(0) is not None:
+            encodings.insert(0, device_encoding(0))
+        if locale.getpreferredencoding() is not None:
+            encodings.insert(0, locale.getpreferredencoding())
+
+        self.assertListEqual(
+            list(get_encodings()),
+            encodings,
+        )
+
+    def test_get_file_content(self):
+        with open("test.json") as file:
+            self.assertDictEqual(
+                json.loads(get_file_content("test.json", encoding="latin-1")),
+                json.load(file),
+            )
+
+    def test_get_real_path(self):
+        self.assertIsNone(get_real_path(None))
+        self.assertEqual("test.json", get_real_path("test.json"))
+        self.assertEqual(
+            path.normcase(server_path + "/static/html/utils.html").lower(),
+            get_real_path("static/html/utils.html").lower(),
+        )
+
+        if platform.system() == "Windows":
+            self.assertEqual(
+                r"C:\WINDOWS\system32\cmd.exe".lower(),
+                get_real_path(r"C:\WINDOWS\system32\cmd.exe").lower(),
+            )
+        else:
+            self.assertEqual(
+                "/etc/passwd",
+                get_real_path("/etc/passwd"),
+            )
+
+        with self.assertRaises(FileNotFoundError):
+            get_real_path("test.test")
+
+    def test_get_ip(self):
+        env = {
+            "X_REAL_IP": "ip1",
+            "X_FORWARDED_FOR": "ip2",
+            "X_FORWARDED_HOST": "ip3",
+            "REMOTE_ADDR": "ip4",
+        }
+
+        self.assertEqual(get_ip(env), "ip1")
+        env.pop("X_REAL_IP")
+        self.assertEqual(get_ip(env), "ip2")
+        env.pop("X_FORWARDED_FOR")
+        self.assertEqual(get_ip(env), "ip3")
+        env.pop("X_FORWARDED_HOST")
+        self.assertEqual(get_ip(env), "ip4")
+
+    def test_get_ini_dict(self):
+        self.assertDictEqual({"test": {"test": "test"}}, get_ini_dict("test.ini"))
+
+
 if __name__ == "__main__":
     main()
